@@ -21,8 +21,8 @@ import sys
 
 from .visualization import *
 from .dataloader import Individual_Dataset
-import variable
-import scheme_var
+from . import variable
+from . import scheme_var
 from .train_test import Test, Scheme
 
 
